@@ -1,5 +1,6 @@
-__all__ = ["cli"]
+__all__ = ["cli", "log"]
 
-from .base import cli
+from .base import ZbxCommand
 from .base import ZbxCommon
-from .base import ZbxCommand
\ No newline at end of file
+from .base import cli
+from .base import log
