@@ -48,6 +48,35 @@ PLATFORM = platform.system().lower()
 PYTHON_PATH = '/usr/bin/python'
 
 
+
+def try_except(tries=0, interval=1):
+    def decorate(func):
+        import functools
+
+        @functools.wraps(func)
+        def wrapper(*args, **kwargs):
+            count = 0
+            while True:
+                try:
+                    result = func(*args, **kwargs)
+                except Exception as e:
+                    import traceback
+                    logger.error(traceback.format_exc())
+                    count += 1
+                    if count > tries:
+                        if tries != 0:
+                            logger.error('retry max times')
+                        break
+                    else:
+                        time.sleep(interval)
+                else:
+                    return result
+
+        return wrapper
+
+    return decorate
+
+
 def init_log():
     dirs = ['/tmp/', '/var/', '/etc/', '/bin/', '/var/log/']
     for d in dirs:
@@ -84,6 +113,45 @@ def init_log():
     file_handler.setFormatter(formatter)
     logger.addHandler(file_handler)
     logger.setLevel(logging.DEBUG)
+
+    @try_except()
+    def set_options(*args, **kwargs):
+        filename = client_log_filename
+        maxBytes = 100 * 1024 * 1024
+        backupCount = 3
+        level = logging.DEBUG
+        # print log message to console
+        console = logging.StreamHandler()
+        isLogConsole = True
+        log_fmt_str = '%(asctime)-25s %(module)s:%(lineno)d  %(levelname)-8s %(message)s'
+        if 'filename' in kwargs:
+            filename = kwargs['filename']
+            log_dir = os.path.dirname(filename)
+            if not os.path.exists(log_dir):
+                os.mkdir(log_dir)
+        if 'maxBytes' in kwargs:
+            maxBytes = kwargs['maxBytes']
+        if 'backupCount' in kwargs:
+            backupCount = kwargs['backupCount']
+        if 'level' in kwargs:
+            level = kwargs['level']
+        if 'log_fmt_str' in kwargs:
+            log_fmt_str = kwargs['log_fmt_str']
+        if 'isLogConsole' in kwargs:
+            isLogConsole = kwargs['isLogConsole']
+        file_handler_new = RotatingFileHandler(filename=filename, maxBytes=maxBytes, backupCount=backupCount)
+        logger.handlers = []
+        formatter = logging.Formatter(log_fmt_str)
+        file_handler_new.setLevel(level)
+        file_handler_new.setFormatter(formatter)
+        logger.addHandler(file_handler_new)
+        if isLogConsole:
+            console.setLevel(level)
+            console.setFormatter(formatter)
+            logger.addHandler(console)
+        logger.setLevel(level)
+
+    setattr(logger, 'set_options', set_options)
     if user == 'root' and PLATFORM != 'windows':
         try:
             if len(os.popen('command -v chattr').read()) > 1:
@@ -130,9 +198,10 @@ class ZbxCommon(object):
         self.auth_uuid = ''
         self.token = ''
         self.modules = {'zmq': 'pyzmq==19.0.2', 'pymysql': 'PyMySQL==0.9.2', 'kafka': 'kafka==1.3.5',
-                        'redis': 'redis==3.5.3', 'yaml': 'PyYAML==5.3.1', 'pyquery': 'pyquery==1.4.3',
+                        'redis': 'redis==3.5.3', 'yaml': 'PyYAML==5.3.1', 'pyquery': 'pyquery==1.4.0',
                         'elasticsearch': 'elasticsearch==7.17.4', 'flask': 'Flask==1.0.2',
-                        'requests': 'requests==2.25.0', 'pymongo': 'pymongo==3.12.3'}
+                        'requests': 'requests==2.25.0', 'pymongo': 'pymongo==3.12.3', 'openpyxl': 'openpyxl==2.6.4',
+                        'xlrd': 'xlrd==2.0.1', 'jinja2': 'Jinja2==2.11.1', 'dsnparse': 'dsnparse==0.1.15'}
         if PY3:
             self.modules['kafka'] = 'kafka-python==2.0.2'
             self.modules['zmq'] = 'pyzmq==23.2.0'
@@ -140,6 +209,9 @@ class ZbxCommon(object):
             self.modules['pymysql'] = 'PyMySQL==1.0.2'
             self.modules['elasticsearch'] = 'elasticsearch==8.3.1'
             self.modules['pymongo'] = 'pymongo==4.2.0'
+            self.modules['openpyxl'] = 'openpyxl==3.0.10'
+            self.modules['xlrd'] = 'xlrd==2.0.1'
+            self.modules['jinja2'] = 'Jinja2==3.1.2'
 
         if len(sys.argv) == 2 and len(sys.argv[1]) == 36:
             self.get_param('')
@@ -150,7 +222,7 @@ class ZbxCommon(object):
         for k, v in self.modules.items():
             mods.append(v)
         if path != '':
-            with open(path + '/requirement.txt', 'w+') as fp:
+            with open(path + '/requirement_cli.txt', 'w+') as fp:
                 fp.write("\n".join(mods))
         else:
             if PY3:
@@ -161,6 +233,10 @@ class ZbxCommon(object):
                     install_mods.append('pip install %s' % (m))
         return "\n".join(install_mods)
 
+    @classmethod
+    def hook_exception(cls):
+        sys.excepthook = handle_exception
+
     def init_log(self):
         pass
         # global logger, log, IS_INIT_GLOBAL_LOG
@@ -565,6 +641,14 @@ class ZbxCommon(object):
         else:
             return ''
 
+    @classmethod
+    def http_get(cls, *args, **kwargs):
+        return cli.requests.get(*args, **kwargs)
+
+    @classmethod
+    def http_post(cls, *args, **kwargs):
+        return cli.requests.post(*args, **kwargs)
+
     def _set_config(self, key, value):
         home = os.path.expanduser('~')
         fn = home + '/.cli'
@@ -2101,46 +2185,23 @@ def handle_exception(exc_type, exc_value, exc_traceback):
     logger.error("Uncaught exception", exc_info=(exc_type, exc_value, exc_traceback))
 
 
-sys.excepthook = handle_exception
+# sys.excepthook = handle_exception
 
 
-def try_except(tries=0, interval=1):
-    def decorate(func):
-        import functools
-
-        @functools.wraps(func)
-        def wrapper(*args, **kwargs):
-            count = 0
-            while True:
-                try:
-                    result = func(*args, **kwargs)
-                except Exception as e:
-                    import traceback
-                    logger.error(traceback.format_exc())
-                    count += 1
-                    if count > tries:
-                        if tries != 0:
-                            logger.error('retry max times')
-                        break
-                    else:
-                        time.sleep(interval)
-                else:
-                    return result
-
-        return wrapper
-
-    return decorate
-
 
 @cli.try_except()
 def __check_module():
-    mds = cli.get_dependencies()
+    mds = cli.modules
+    cli.gen_requirements('.')
     if len(mds) > 0:
         for m in mds:
             try:
                 __import__(m)
             except Exception as err:
-                logger.warning('No module named: %s' % (m))
+                if PY3:
+                    logger.warning('No module named: pip3 install %s' % (cli.modules[m]))
+                else:
+                    logger.warning('No module named: pip install %s' % (cli.modules[m]))
 
 
 __check_module()
@@ -2297,6 +2358,8 @@ HELP_DOC = '''
 
 
 EXAMPLE_DOC = '''
+from ops_channel import cli,log
+log.set_options(filename='/tmp/xxx.log', maxBytes=1024*1024, backupCount=3, level=logging.DEBUG,isLogConsole=True)
 dsn = os.environ.get("DSN", "mysql://root:root@127.0.0.1:3306/pjm_db")
 
 dsn='mysql://root:root@localhost:3306/ferry'
