@@ -313,15 +313,15 @@ Exit:4->5
 
 # cli.dump_sqlite_data(conn,'/tmp/test')
 
-dsn='mysql://root:mock@127.0.0.1:63307/mock'
-
-conn = cli.get_mysql_connection(dsn)
-
-
-sql='select * from step_tab limit 2000'
-
-
-data=cli.mysql_query(conn,sql)
+# dsn='mysql://root:mock@127.0.0.1:63307/mock'
+#
+# conn = cli.get_mysql_connection(dsn)
+#
+#
+# sql='select * from step_tab limit 2000'
+#
+#
+# data=cli.mysql_query(conn,sql)
 
 
 
@@ -336,5 +336,14 @@ data=cli.mysql_query(conn,sql)
 # print(data)
 
 
-cli.dump_csv(data,'/Users/junqiang.zhang/Downloads/data1.csv')
+# cli.dump_csv(data,'/Users/junqiang.zhang/Downloads/data1.csv')
 
+log.error("xxx")
+
+log.set_options(filename='/tmp/xxx.log', maxBytes=1024*1024, backupCount=3, level=logging.DEBUG,isLogConsole=True)
+
+log.error("xxx")
+
+
+
+cli.http_get('http://www.baidu.com',headers={'User-Agent':'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/77.0.3865.90 Safari/537.36'})
